from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

CPU_NXP_6800 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'MC6800', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC6800'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC68A00L.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC6800\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Phi1',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='DBE',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='Phi2',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='39',name='TSC',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VMA',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC6802', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC6802'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'https://www.jameco.com/Jameco/Products/ProdDS/43502.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC6802\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='VCC_STANDBY',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='RE',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='XTAL',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='EXTAL',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VMA',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC6809', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC6809'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC68B09S.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC6809\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='~{DMA/BREQ}',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='MRDY',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='XTAL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{FIRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='BS',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='A0',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='A1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC6809E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC6809E'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC68B09S.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC6809E\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='Q',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='AVMA',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='LIC',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='TSC',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{FIRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='BS',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='A0',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='A1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68A00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68A00'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC68A00L.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC68A00\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Phi1',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='DBE',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='Phi2',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='39',name='TSC',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VMA',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68A02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68A02'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'https://www.jameco.com/Jameco/Products/ProdDS/43502.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC68A02\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='VCC_STANDBY',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='RE',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='XTAL',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='EXTAL',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VMA',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68A09', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68A09'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC68B09S.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC68A09\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='~{DMA/BREQ}',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='MRDY',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='XTAL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{FIRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='BS',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='A0',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='A1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68A09E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68A09E'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC68B09S.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC68A09E\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='Q',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='AVMA',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='LIC',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='TSC',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{FIRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='BS',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='A0',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='A1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68B00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68B00'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC68A00L.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC68B00\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Phi1',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='DBE',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='Phi2',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='39',name='TSC',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VMA',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68B02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68B02'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'https://www.jameco.com/Jameco/Products/ProdDS/43502.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC68B02\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='VCC_STANDBY',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='RE',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='XTAL',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='EXTAL',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VMA',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68B09', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68B09'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC68B09S.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC68B09\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='~{DMA/BREQ}',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='E',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='MRDY',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='XTAL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{FIRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='BS',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='A0',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='A1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68B09E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68B09E'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'MCU', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC68B09S.pdf', 'search_text':'/usr/share/kicad/symbols/CPU_NXP_6800.kicad_sym\nMC68B09E\n\nMCU', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{NMI}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{IRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='R/~{W}',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='Q',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='AVMA',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='LIC',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='TSC',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{FIRQ}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{HALT}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='BS',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BA',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='A0',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='A1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_NXP_NTAG = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'NHS3100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NHS3100'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'NFC Cortex-M0', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/NHS3100.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_NTAG.kicad_sym\nNHS3100\n\nNFC Cortex-M0', 'pins':[
            Pin(num='1',name='P0/WAKEUP',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='P4/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P5/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P7/CT16B_M1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3/CT16B_M0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P10/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P11/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='LB',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P1/CLKOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='LA',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P2/SSEL',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6/SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P8/MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P9/MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Logic_LevelTranslator = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'74LVC2T45DC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2T45DC'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74LVC_LVCH2T45.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\n74LVC2T45DC\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1A',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='2A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='2B',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='1B',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FXMA108', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FXMA108'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-20-1EP_2.5x4.5mm_P0.5mm_EP1x2.9mm'], 'footprint':'Package_DFN_QFN:WQFN-20-1EP_2.5x4.5mm_P0.5mm_EP1x2.9mm', 'keywords':'Level shifter translator bidirectional', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/FXMA108-D.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nFXMA108\n\nLevel shifter translator bidirectional', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='B7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='B0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCN4555MN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCN4555MN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.75x1.75mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.75x1.75mm', 'keywords':'SIM Card Level Shifter', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/NCN4555-D.PDF', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nNCN4555MN\n\nSIM Card Level Shifter', 'pins':[
            Pin(num='1',name='~{STOP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='I/O',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='MOD_VCC',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='SIM_VCC',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='SIM_I/O',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SIM_RST',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NLSV2T244D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NLSV2T244D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/NLSV2T244-D.PDF', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nNLSV2T244D\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='B2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='B1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NLSV2T244DM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NLSV2T244DM'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/NLSV2T244-D.PDF', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nNLSV2T244DM\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='B2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='B1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NLSV2T244MU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NLSV2T244MU'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:OnSemi_UDFN-8_1.2x1.8mm_P0.4mm'], 'footprint':'Package_DFN_QFN:OnSemi_UDFN-8_1.2x1.8mm_P0.4mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/NLSV2T244-D.PDF', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nNLSV2T244MU\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='B2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='B1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74AUP1T34DCK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74AUP1T34DCK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'Noninverting', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74aup1t34.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74AUP1T34DCK\n\nNoninverting', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN),
            Pin(num='2',name='A',func=pin_types.INPUT),
            Pin(num='3',name='GND',func=pin_types.PWRIN),
            Pin(num='4',name='B',func=pin_types.OUTPUT),
            Pin(num='5',name='VCCB',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74AVC4T245PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74AVC4T245PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'Noninverting Bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74avc4t245.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74AVC4T245PW\n\nNoninverting Bidirectional', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='2B2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='2B1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='1B2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='1B1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1DIR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='2DIR',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='1A1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='1A2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='2A1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='2A2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74AVC8T245PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74AVC8T245PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'Noninverting Bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74avc8t245.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74AVC8T245PW\n\nNoninverting Bidirectional', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='B8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='B7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LV1T125DCK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LV1T125DCK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'single buffer level shift', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lv1t125.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74LV1T125DCK\n\nsingle buffer level shift', 'pins':[
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LV1T34DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LV1T34DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'single buffer level shift', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lv1t34.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74LV1T34DBV\n\nsingle buffer level shift', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LV1T34DCK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LV1T34DCK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'single buffer level shift', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lv1t34.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74LV1T34DCK\n\nsingle buffer level shift', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC1T45DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC1T45DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1t45.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74LVC1T45DBV\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='B',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC1T45DCK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC1T45DCK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1t45.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74LVC1T45DCK\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='B',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC1T45DRL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC1T45DRL'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-563'], 'footprint':'Package_TO_SOT_SMD:SOT-563', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1t45.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74LVC1T45DRL\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='B',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC245APW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC245APW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Noninverting Bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/scas218x/scas218x.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74LVC245APW\n\nNoninverting Bidirectional', 'pins':[
            Pin(num='1',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='B8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='B7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC2T45DCUR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC2T45DCUR'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc2t45.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74LVC2T45DCUR\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC2T45YZP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC2T45YZP'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-8_0.9x1.9mm_Layout2x4_P0.5mm'], 'footprint':'Package_BGA:Texas_DSBGA-8_0.9x1.9mm_Layout2x4_P0.5mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc2t45.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74LVC2T45YZP\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='A1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='DIR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC8T245', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC8T245'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Supply Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc8t245.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74LVC8T245\n\nDual Supply Level-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='B8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='B7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='V_{CCB}',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='V_{CCB}',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9517ADGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9517ADGK'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'I2C buffer repeater', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tca9517a.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTCA9517ADGK\n\nI2C buffer repeater', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SDAA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='EN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='SDAB',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCLB',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0101DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0101DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'bidirectional voltage level translator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0101.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0101DBV\n\nbidirectional voltage level translator', 'pins':[
            Pin(num='1',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='B',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{CCB}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0101YZP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0101YZP'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'bidirectional voltage level translator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0101.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0101YZP\n\nbidirectional voltage level translator', 'pins':[
            Pin(num='A1',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='V_{CCB}',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='C1',name='A',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='B',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0102DCT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0102DCT'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_3x3mm_P0.65mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0102.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0102DCT\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='B1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0102DCU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0102DCU'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0102.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0102DCU\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='B1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0102YZP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0102YZP'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-8_0.9x1.9mm_Layout2x4_P0.5mm'], 'footprint':'Package_BGA:Texas_DSBGA-8_0.9x1.9mm_Layout2x4_P0.5mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0102.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0102YZP\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='A1',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='A1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0104D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0104D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0104.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0104D\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0104PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0104PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0104.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0104PW\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0104RGY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0104RGY'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_S-PVQFN-N14'], 'footprint':'Package_DFN_QFN:Texas_S-PVQFN-N14', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0104.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0104RGY\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='Pad',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0104RUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0104RUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_R-PUQFN-N12'], 'footprint':'Package_DFN_QFN:Texas_R-PUQFN-N12', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0104.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0104RUT\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='B2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0104YZT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0104YZT'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-12_1.36x1.86mm_Layout3x4_P0.5mm'], 'footprint':'Package_BGA:Texas_DSBGA-12_1.36x1.86mm_Layout3x4_P0.5mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0104.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0104YZT\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='A1',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='C3',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='A4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0104ZXU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0104ZXU'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-12_2.0x2.5mm_Layout4x3_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-12_2.0x2.5mm_Layout4x3_P0.5mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0104.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0104ZXU\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='A1',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='B4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0106PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0106PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'bidirectional voltage level translator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0106.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0106PW\n\nbidirectional voltage level translator', 'pins':[
            Pin(num='1',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='V_{CCB}',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0106RGY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0106RGY'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGY_R-PVQFN-N16_EP2.05x2.55mm'], 'footprint':'Package_DFN_QFN:Texas_RGY_R-PVQFN-N16_EP2.05x2.55mm', 'keywords':'bidirectional voltage level translator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0106.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0106RGY\n\nbidirectional voltage level translator', 'pins':[
            Pin(num='1',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='V_{CCB}',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0108DQSR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0108DQSR'}), 'ref_prefix':'U', 'fplist':['Package_SON:USON-20_2x4mm_P0.4mm'], 'footprint':'Package_SON:USON-20_2x4mm_P0.4mm', 'keywords':'bidirectional voltage level translator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0108.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0108DQSR\n\nbidirectional voltage level translator', 'pins':[
            Pin(num='1',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='A8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='B8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='B7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0108PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0108PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'bidirectional voltage level translator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0108.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0108PW\n\nbidirectional voltage level translator', 'pins':[
            Pin(num='1',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='B8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='V_{CCB}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0108RGY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0108RGY'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGY_R-PVQFN-N20_EP2.05x3.05mm'], 'footprint':'Package_DFN_QFN:Texas_RGY_R-PVQFN-N20_EP2.05x3.05mm', 'keywords':'bidirectional voltage level translator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0108.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0108RGY\n\nbidirectional voltage level translator', 'pins':[
            Pin(num='1',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='B8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='V_{CCB}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXBN0304RUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXBN0304RUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_R-PUQFN-N12'], 'footprint':'Package_DFN_QFN:Texas_R-PUQFN-N12', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0304.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXBN0304RUT\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='B2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXS0101DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXS0101DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/txs0101.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXS0101DBV\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='B',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{CCB}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXS0101YZP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXS0101YZP'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-6_0.9x1.4mm_Layout2x3_P0.5mm'], 'footprint':'Package_BGA:Texas_DSBGA-6_0.9x1.4mm_Layout2x3_P0.5mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/txs0101.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXS0101YZP\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='A1',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='V_{CCB}',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='C1',name='A',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='B',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXS0102DCT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXS0102DCT'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-8_2.95x2.8mm_P0.65mm'], 'footprint':'Package_SO:SSOP-8_2.95x2.8mm_P0.65mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/txs0102', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXS0102DCT\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='B1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXS0102DCU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXS0102DCU'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/txs0102', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXS0102DCU\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='B1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXS0102DQE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXS0102DQE'}), 'ref_prefix':'U', 'fplist':['Package_SON:X2SON-8_1.4x1mm_P0.35mm'], 'footprint':'Package_SON:X2SON-8_1.4x1mm_P0.35mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/txs0102', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXS0102DQE\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXS0102YZP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXS0102YZP'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-8_0.9x1.9mm_Layout2x4_P0.5mm'], 'footprint':'Package_BGA:Texas_DSBGA-8_0.9x1.9mm_Layout2x4_P0.5mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/txs0102', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXS0102YZP\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='A1',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='A1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXS0108EPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXS0108EPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'8-bit', 'description':'', 'datasheet':'www.ti.com/lit/ds/symlink/txs0108e.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXS0108EPW\n\n8-bit', 'pins':[
            Pin(num='1',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='B8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXS02612RTW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXS02612RTW'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm_ThermalVias'], 'footprint':'Package_DFN_QFN:WQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm_ThermalVias', 'keywords':'SDIO level translator', 'description':'', 'datasheet':'https://www.ti.com/lit/gpn/TXS02612', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXS02612RTW\n\nSDIO level translator', 'pins':[
            Pin(num='1',name='DAT2A',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DAT3_{B1}',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CMD_{B1}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CLK_{B1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DAT0_{B1}',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DAT1_{B1}',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DAT1_{B0}',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC_{B1}',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='DAT0_{B0}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CLK_{B0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='CMD_{B0}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC_{B0}',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DAT3_{B0}',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DAT2_{B0}',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SEL',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DAT3A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CMDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DAT0A',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DAT1A',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DAT2_{B1}',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CLKA',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVCH2T45DC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVCH2T45DC'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74LVC_LVCH2T45.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\n74LVCH2T45DC\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1A',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='2A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='2B',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='1B',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LV1T125DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LV1T125DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'single buffer level shift', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lv1t125.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nSN74LV1T125DBV\n\nsingle buffer level shift', 'pins':[
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9517D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9517D'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'I2C buffer repeater', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tca9517.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTCA9517D\n\nI2C buffer repeater', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SDAA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='EN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='SDAB',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCLB',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0101DCK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0101DCK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'bidirectional voltage level translator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0101.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0101DCK\n\nbidirectional voltage level translator', 'pins':[
            Pin(num='1',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='B',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{CCB}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0101DRL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0101DRL'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-563'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'bidirectional voltage level translator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0101.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0101DRL\n\nbidirectional voltage level translator', 'pins':[
            Pin(num='1',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='B',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{CCB}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXB0304RUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXB0304RUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_R-PUQFN-N12', 'Package_DFN_QFN:Texas_R-PUQFN-N12'], 'footprint':'Package_DFN_QFN:Texas_R-PUQFN-N12', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/txb0304.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXB0304RUT\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='B2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXS0101DCK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXS0101DCK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/txs0101.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXS0101DCK\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='B',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{CCB}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TXS0101DRL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TXS0101DRL'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-563'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Level-Shifter CMOS-TTL-Translation', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/txs0101.pdf', 'search_text':'/usr/share/kicad/symbols/Logic_LevelTranslator.kicad_sym\nTXS0101DRL\n\nLevel-Shifter CMOS-TTL-Translation', 'pins':[
            Pin(num='1',name='V_{CCA}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='B',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{CCB}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])